@@ -29,6 +29,7 @@
 
 #include <config.h>
 #include <libspi/listener.h>
+#include "spi-private.h"
 
 /* Our parent Gtk object type */
 #define PARENT_TYPE BONOBO_TYPE_OBJECT
@@ -36,6 +37,8 @@
 /* A pointer to our parent object class */
 static GObjectClass *spi_listener_parent_class;
 
+int _dbg = 0;
+
 /*
  * Implemented GObject::finalize
  */
@@ -64,7 +67,7 @@ impl_notify_event (PortableServer_Servant     servant,
   fprintf (stderr, "source name: '%s'\n",
            Accessibility_Accessible__get_name(e->source, ev));
   if (ev->_major != CORBA_NO_EXCEPTION) {
-           DBG (2, g_warning ("Accessibility app error: exception during event notification: %s\n"),
+           DBG (2, g_warning ("Accessibility app error: exception during event notification: %s\n",
 		CORBA_exception_id(ev)));
   }
   /*
@@ -93,9 +96,17 @@ spi_listener_class_init (SpiListenerClass *klass)
         epv->notifyEvent = impl_notify_event;
 }
 
+static void
+spi_listener_set_debug (const char *debug_flag_string)
+{
+  if (debug_flag_string)
+    _dbg = (int) g_ascii_strtod (debug_flag_string, NULL);
+}
+
 static void
 spi_listener_init (SpiListener *listener)
 {
+  spi_listener_set_debug (g_getenv ("AT_SPI_DEBUG"));
 }
 
 BONOBO_TYPE_FUNC_FULL (SpiListener,
