@@ -33,25 +33,31 @@ IBM Corporation under the BSD license, available at
 U{http://www.opensource.org/licenses/bsd-license.php}
 '''
 
-try:
-  gconf = None
-  gconfClient = None
-  import gconf
-  gconfClient = gconf.client_get_default()
-  useDbus = gconfClient.get_bool("/desktop/gnome/interface/at-spi-dbus")
-except:
-  useDbus = False
-finally:
-  del gconfClient
-  del gconf
+# Do not replace yourself if you've been imported explicitly by name
+# already.
+#
+import sys
+if not sys.modules.has_key('pyatspi_corba'):
+    try:
+        gconf = None
+        gconfClient = None
+        import gconf
+        gconfClient = gconf.client_get_default()
+        useDbus = \
+            gconfClient.get_bool("/desktop/gnome/interface/at-spi-dbus")
+    except:
+        useDbus = False
+    finally:
+        del gconfClient
+        del gconf
+else:
+    useDbus = False
 
 if useDbus:
-  import sys
   import pyatspi_dbus
   sys.modules['pyatspi'] = pyatspi_dbus
-  del sys
 else:
-  __version__ = (1, 29, 6)
+  __version__ = (1, 29, 92)
 
   REGISTRY_IID = "OAFIID:Accessibility_Registry:1.0"
   TYPELIB_NAME = "Accessibility"
@@ -90,4 +96,5 @@ else:
   del reg
   del orb
 
+del sys
 del useDbus
